import requests

class GetAllMemberChat:
	def __init__(self, token, command):
		self.token = token
		self.command = command

	def get_json(self, peer_id):
		vk_api = 'https://api.vk.com/method/messages.getConversationMembers?peer_id={0}&fields=sex&access_token={1}&v=5.103'.format(peer_id, self.token)
		call = requests.get(vk_api).json()
		return call

	def get_message(self, peer_id):
		json = self.get_json(peer_id)

		message = "Все участники беседы:\n"
		count = 0

		for item in json['response']['profiles']:
			count += 1
			message = message + "{3}. [id{0}|{1} {2}]\n".format(item['id'], item['first_name'], item['last_name'], count)

		return message

	def get_allmemberchat(self, msg, *args):
		peer_id = args[0]

		if self.command in msg:
			if '200000000' in str(peer_id):
				message = self.get_message(peer_id)
				return message
			else:
				return 'Бот не находится в беседе'







import datetime
import random

from vkbotfather.fatherbot.models.settings import SettingsBot


class Model(SettingsBot):

    def startListen(self):
        """Listens to messages and sends their responses to analyzes"""
        try:
            print('| Server is running\n| For shutdown server press Ctrl + C\n| {0}'.format(datetime.datetime.now()))
            for event in self.vk_api.listenServer():
                if self.vk_api.isNewMessage(event):
                    if self.vk_api.isMessageFromChat(event):
                        self.giveResponse(event['object']['message']['text'], event['object']['message']['peer_id'], 'chat', event['object']['message']['from_id'])
                    elif self.vk_api.isMessageFromUser(event):
                        self.giveResponse(event['object']['message']['text'], event['object']['message']['peer_id'], 'user')

        except KeyboardInterrupt:
            print('| Server shutdown\n| {0}'.format(datetime.datetime.now()))

    def giveResponse(self, event_text, event_user_id, type_message, *args):
        """Takes a response and analyzes it. 
        This function processes requests from only one user. 
        You can change the response processing parameters."""

        print('| {2} :Bot got a message "{0}" <- @{1}'.format(event_text, event_user_id, datetime.datetime.now())) 

        if type_message == 'chat':
            event_from_id = args[0]
            response = self.messageAnalysis(event_text, event_user_id, type_message, event_from_id)
        else:
            response = self.messageAnalysis(event_text, event_user_id, type_message)
        if response is None:
            pass
        else: 
            if len(response) > 3 and response[-3:] in self.image_types:
                self.sendImage(response, event_user_id)
            if len(response) > 3 and response[-3:] in self.document_types:
                self.sendDocument(response, event_user_id)
            else:
                self.sendMessage(response, event_user_id)

    def sendMessage(self, msg, user_id):
        """Sends a text message to the user."""
        self.vk_api.sendMessage(
            peer_id=user_id,
            message=msg,
            random_id=random.randint(1, 10 ** 8)
        )

        print('| {2} :Bot send a message "{0}" -> @{1}'.format(msg, user_id, datetime.datetime.now()))

    def sendImage(self, image, user_id): #Work only one sendImage
        """Sends a image to the user."""
        self.vk_api.sendImage(
            peer_id=user_id, 
            path=image,
            random_id=random.randint(1, 10 ** 8)
        )

        print('| {2} :Bot send a image "{0}" -> @{1}'.format(image, user_id, datetime.datetime.now()))

    def sendDocument(self, document, user_id):
        """Sends a document to the user"""
        self.vk_api.sendDocument(
            peer_id=user_id,
            path=document,
            random_id=random.randint(1, 10 ** 8)
        )

        print('| {2} :Bot send a document "{0}" -> @{1}'.format(document, user_id, datetime.datetime.now()))
    
    def messageAnalysis(self, message, peer_id, type_message, *args):
        """Analyzes messages and return response.
        
        If your response has line breaks, then use double quotes for this."""

        response = None
        for plugin in self.plugins:
            if type_message == 'chat':
                response = plugin(message, peer_id, args[0])
            else:
                response = plugin(message, peer_id)
            if response != None:
                return response
        if response == None:
            print('Yours plugins not have a return message/image/document')

    def addPlugin(self, plugin):
        """Add only one plugin in plugins list."""

        self.plugins.append(plugin)
    
    def addPlugins(self, plugins):
        """Add plugins in plugins list."""

        for plugin in plugins:
            self.addPlugin(plugin)

    def imageTypes(self, types):
        """Add new format images"""

        for typ in types:
            self.image_types.append(typ)

    def documentTypes(self, types):
        """Add new format document"""

        for typ in types:
            self.document_types.append(typ)


import random

class GetWhatChoose:
	def __init__(self, command):
		self.command = command

	def get_message(self, msg):
		
		message = msg[len(self.command)+1:]
		if len(message) > 0:
			first_choise = message[message.find('или')+4:]
			second_choise = message[:-message.find('или')-4]

			random_num = random.randint(1, 2)

			if random_num == 1 and first_choise != '' and first_choise != ' ' and first_choise != None:
				return "Я думаю, что лучше {0}".format(first_choise)
			elif random_num == 2 and second_choise != '' and second_choise != ' ' and second_choise != None:
				return "Я думаю, что лучше {0}".format(second_choise)
		else:
			return '0'


	def get_choise(self, msg, *args):

		if self.command in msg:
			message = self.get_message(msg)
			if message != '0':
				return message
			else:
				pass


import toml

from vkbotfather.utils.config_tool import get_config
from vkbotfather.fatherbot.models.vkapi import VKAPI

class SettingsBot:
    """It contains all the bot settings."""
    def __init__(self, token=None, group_id=None, config=None):

        if token == None and group_id == None:
            self.config = get_config(config)
            self.token = self.config['token']
            self.group_id = self.config['group_id']
        else:
            self.token = token
            self.group_id = group_id
        
        self.vk_api = VKAPI(token=self.token, group_id=self.group_id)

        self.plugins = []

        self.image_types = []

        self.document_types = []


import requests

class VKAPI:
    def __init__(self, token, group_id):
        self.token = token
        self.group_id = group_id
        self.api_link = 'https://api.vk.com/method/{method}'

    def call(self, method, **kwargs):
        """Call method from VK API"""
        params = {}
        params.update(**kwargs)
        params['v'] = '5.103'
        api_url = self.api_link.format(method=method)
        response = requests.get(api_url, params=params).json()

        return response

# Utils
    def openFile(self, path):
        file = open(path, 'rb')
        
        return file


# LongPoll 
    def updateLongpoll(self):
        api_url = 'https://api.vk.com/method/groups.getLongPollServer?access_token={0}&group_id={1}&v=5.103'.format(self.token, self.group_id)
        response = requests.get(api_url).json()

        server_url = response['response']['server']
        key = response['response']['key']
        ts = response['response']['ts']

        return server_url, key, ts

    def checkLongpoll(self):
        """Check LongPoll server on new updates"""
        server_url, key, ts = self.updateLongpoll()
        longoll_url = '{0}?act=a_check&key={1}&wait=25&mode=2&ts={2}'.format(server_url, key, ts)
        longoll_get = requests.get(longoll_url).json()
        ts = longoll_get['ts']
        updates = longoll_get['updates']

        return updates

    def listenServer(self):
        while True:
            for event in self.checkLongpoll():
                yield event

# UploadServer 
    def uploadImage(self, peer_id, path):
        """Upload and save images ONLY for message
        
        peer_id - user id to whom the image is sent
        path - path of image file

        """
        upload_server = self.call('photos.getMessagesUploadServer', peer_id=peer_id, access_token=self.token)

        image = self.openFile(path)

        post_url = upload_server['response']['upload_url']
        post_response = requests.post(post_url, files=dict(file=image)).json()
        server, photo, vk_hash = post_response['server'], post_response['photo'], post_response['hash']

        save_response = self.call('photos.saveMessagesPhoto', photo=photo, server=server, hash=vk_hash, access_token=self.token)
        upload_image = 'photo{0}_{1}'.format(save_response['response'][0]['owner_id'], save_response['response'][0]['id'])

        return upload_image

    def uploadDocument(self, peer_id, path):
        """Upload and save documents ONLY for message 
        
        peer_id - user id to whom the image is sent
        path - path of image file
        
        """
        upload_server = self.call('docs.getMessagesUploadServer', type='doc', peer_id=peer_id, access_token=self.token)

        document = self.openFile(path)

        post_url = upload_server['response']['upload_url']
        post_response = requests.post(post_url, files=dict(file=document)).json()
        document = post_response['file']

        save_response = self.call('docs.save', file=document, access_token=self.token)
        upload_document = 'doc{0}_{1}'.format(save_response['response']['doc']['owner_id'], save_response['response']['doc']['id'])
      
        return upload_document

# Messages
    def sendImage(self, peer_id, path, random_id):
        """Send Image ONLY for message
        
        peer_id - user id to whom the image is sent
        path - path of image file
        random_id - random integer number, but use a random.randint(1, 10 ** 8)

        """
        photo = self.uploadImage(peer_id, path)
        response_send = self.call('messages.send', attachment=photo, peer_id=peer_id, access_token=self.token, random_id=random_id)

        return response_send  
    
    def sendDocument(self, peer_id, path, random_id):
        """Send Document ONLY for message
        
        peer_id - user id to whom the image is sent
        path - path of image file
        random_id - random integer number, but use a random.randint(1, 10 ** 8)
        
        """

        document = self.uploadDocument(peer_id, path)
        response_send = self.call('messages.send', attachment=document, peer_id=peer_id, access_token=self.token, random_id=random_id)

        return response_send
    
    def sendMessage(self, message, peer_id, random_id):
        """Send message
        
        peer_id - user id to whom the image is sent
        random_id - random integer number, but use a random.randint(1, 10 ** 8)
        
        """
        response = self.call('messages.send', peer_id=peer_id, message=message, random_id=random_id, access_token=self.token)

        return response

# Type message
    def isNewMessage(self, event):
        """Check message type
        
        event - variable that save updates from listenServer()

        """
        if event['type'] == 'message_new':
            return True
        return False

    def isMessageFromChat(self, event):
        """Check from message

        event - variable that save updates from listenServer()

        """
        if '200000000' in str(event['object']['message']['peer_id']):
            return True
        return False

    def isMessageFromUser(self, event):
        """Check from message

        event - variable that save updates from listenServer()

        """
        if not '200000000' in str(event['object']['message']['peer_id']):
            return True
        return False


import requests


class KickUser:
	def __init__(self, word_list, token):
		self.word_list = word_list
		self.token = token

	def get_json(self, chat_id, user_id):
		vk_api = 'https://api.vk.com/method/messages.removeChatUser?chat_id={0}&user_id={1}&access_token={2}&v=5.103'.format(chat_id, user_id, self.token)
		call = requests.get(vk_api).json()
		return call

	def get_message(self, chat_id, user_id):
		json = self.get_json(chat_id, user_id)

		message = "За использованние запрещенных слов\n"

		return message

	def get_kickuser(self, msg, *args):
		chat_id = args[0]
		user_id = args[1]

		new_chat_id = ''

		for word in self.word_list:
			if word in msg:
				if '200000000' in str(chat_id):
					for i in str(chat_id):
						if i != '0':
							new_chat_id += i
		
        message = self.get_message(new_chat_id[1:], user_id)
        return message

				else:
					pass


from vkbotfather.fatherbot.models.settings import SettingsBot
from vkbotfather.fatherbot.models.model import Model

from vkbotfather.utils.config_tool import get_config

class MakeBot(SettingsBot):
    def __init__(self, token=None, group_id=None, config=None):      
        SettingsBot.__init__(self, token, group_id, config)
        self.model = Model(token, group_id, config)
    
    def startBot(self):
        self.model.startListen()
    


import requests

class GetInfoUser:
    def __init__(self, command, token):
        self.command = command
        self.token =  token
    
    def get_json(self, user_id):
        vk_api = 'https://api.vk.com/method/users.get?user_ids={0}&access_token={1}&v=5.103'.format(user_id, self.token)

        call = requests.get(vk_api).json()

        return call

    def get_message(self, msg):

        user_id = msg[len(self.command)+1:]

        json =  self.get_json(user_id)

        print(json)

        message = 'Неверно введен ID или некоректная работа плагина'

        try:
            message = "Информация о пользователе:\n Имя: {0}\nФамилия: {1}\nID: {2}\nЗакрыт/Открыт профиль: {3}\nСсылка на профиль: {4}".format(
                            json['response'][0]['first_name'], 
                            json['response'][0]['last_name'],
                            json['response'][0]['id'],
                            json['response'][0]['is_closed'],
                            'vk.com/id' + str(json['response'][0]['id'])
                        )
        except:
            pass


        return message

    def get_infouser(self, msg, *args):
        if self.command in msg:
            message = self.get_message(msg)

            return message





class GetTalk:
	def __init__(self, words):
		self.words = words

	def get_message(self, item):

		message = self.words[item]
		return message

	def get_talk(self, msg, *args):

		zero_message = False

		for item in self.words:
			if item in msg:
				message = self.get_message(item)
				zero_message = True
				return message

		if zero_message == False:
			message = 'Я не понимаю вас'
			return message



import requests 

class GetAllMember:
	def __init__(self, group_id, token, command):
		self.group_id = group_id
		self.token = token
		self.vk_api = 'https://api.vk.com/method/groups.getMembers?group_id={0}&fields=sex&access_token={1}&v=5.103'.format(self.group_id, self.token)
		self.command = command

	def get_json(self):
		call = requests.get(self.vk_api).json()
		return call 

	def get_message(self):
		json = self.get_json()

		message = "Список всех подписчиков:\n"
		count = 0

		for item in json['response']['items']:
			count += 1 
			message = message + "{3}. [id{0}|{1} {2}]\n".format(item['id'], item['first_name'], item['last_name'], count)

		return message

	def get_allmembers(self, msg, *args):
		if self.command in msg:
			message = self.get_message()
			return message



import requests


class GetIsMember:
    def __init__(self, token, group_id, command):
        self.group_id = group_id
        self.command = command
        self.token = token
  
    def get_json(self, user_id):
        vk_api = 'https://api.vk.com/method/groups.isMember?group_id={0}&user_id={1}&access_token={2}&v=5.103'.format(self.group_id, user_id, self.token)
        call = requests.get(vk_api).json()

        return call
  
    def get_message(self, msg):
        user_id = msg[len(self.command)+1:]

        call = self.get_json(user_id)

        if call['response'] == 1:
            return 'Данный пользователь является участником сообщества'
        return 'Данный пользователь не является участником сообщества'
  
    def get_ismember(self, msg, *args):
        if self.command in msg:
        message = self.get_message(msg)

        return message



from setuptools import setup, find_packages


setup(
    name='vkbotfather',
    description='Father for creating VK Bots',
    version='0.2.8',
    url='https://github.com/wultes/vkbotfather',
    license='MIT',
    author='Wultes (Kirill)',
    author_email='wultesu@gmail.com',
    packages=find_packages(),
    install_requires=['toml', 'Pillow', 'requests'],
)



import random

class WhatRandom:
	def __init__(self, command):
		self.command = command

	def get_message(self):

		rand = random.randint(0, 100)

		message = "Вероятность этого равна {0}%".format(rand)

		return message

	def get_random(self, msg, *args):
		if self.command in msg:
			message = self.get_message()
			return message




import toml

def get_config(path_config):

    config = {}

    with open(path_config, 'r', encoding='utf-8') as config_file:
        for line in config_file:
            if line not in config:
                for key, value in toml.load(config_file).items():
                    config[key] = value

    return config